@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2015-2016 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -23,9 +23,9 @@
 
 #include "kcontacts_export.h"
 
-#include <QtCore/QSharedDataPointer>
-#include <QtCore/QString>
-#include <QtCore/QMap>
+#include <QSharedDataPointer>
+#include <QString>
+#include <QMap>
 class QUrl;
 /** @short Class that holds a Resource Locator
  *  @since 5.0
